# coding: utf-8

"""
    rds_mysql_v2

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ParameterForDescribeDBInstanceParametersOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'checking_code': 'str',
        'force_restart': 'bool',
        'parameter_default_value': 'str',
        'parameter_description': 'str',
        'parameter_name': 'str',
        'parameter_value': 'str'
    }

    attribute_map = {
        'checking_code': 'CheckingCode',
        'force_restart': 'ForceRestart',
        'parameter_default_value': 'ParameterDefaultValue',
        'parameter_description': 'ParameterDescription',
        'parameter_name': 'ParameterName',
        'parameter_value': 'ParameterValue'
    }

    def __init__(self, checking_code=None, force_restart=None, parameter_default_value=None, parameter_description=None, parameter_name=None, parameter_value=None, _configuration=None):  # noqa: E501
        """ParameterForDescribeDBInstanceParametersOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._checking_code = None
        self._force_restart = None
        self._parameter_default_value = None
        self._parameter_description = None
        self._parameter_name = None
        self._parameter_value = None
        self.discriminator = None

        if checking_code is not None:
            self.checking_code = checking_code
        if force_restart is not None:
            self.force_restart = force_restart
        if parameter_default_value is not None:
            self.parameter_default_value = parameter_default_value
        if parameter_description is not None:
            self.parameter_description = parameter_description
        if parameter_name is not None:
            self.parameter_name = parameter_name
        if parameter_value is not None:
            self.parameter_value = parameter_value

    @property
    def checking_code(self):
        """Gets the checking_code of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501


        :return: The checking_code of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :rtype: str
        """
        return self._checking_code

    @checking_code.setter
    def checking_code(self, checking_code):
        """Sets the checking_code of this ParameterForDescribeDBInstanceParametersOutput.


        :param checking_code: The checking_code of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :type: str
        """

        self._checking_code = checking_code

    @property
    def force_restart(self):
        """Gets the force_restart of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501


        :return: The force_restart of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :rtype: bool
        """
        return self._force_restart

    @force_restart.setter
    def force_restart(self, force_restart):
        """Sets the force_restart of this ParameterForDescribeDBInstanceParametersOutput.


        :param force_restart: The force_restart of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :type: bool
        """

        self._force_restart = force_restart

    @property
    def parameter_default_value(self):
        """Gets the parameter_default_value of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501


        :return: The parameter_default_value of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :rtype: str
        """
        return self._parameter_default_value

    @parameter_default_value.setter
    def parameter_default_value(self, parameter_default_value):
        """Sets the parameter_default_value of this ParameterForDescribeDBInstanceParametersOutput.


        :param parameter_default_value: The parameter_default_value of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :type: str
        """

        self._parameter_default_value = parameter_default_value

    @property
    def parameter_description(self):
        """Gets the parameter_description of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501


        :return: The parameter_description of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :rtype: str
        """
        return self._parameter_description

    @parameter_description.setter
    def parameter_description(self, parameter_description):
        """Sets the parameter_description of this ParameterForDescribeDBInstanceParametersOutput.


        :param parameter_description: The parameter_description of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :type: str
        """

        self._parameter_description = parameter_description

    @property
    def parameter_name(self):
        """Gets the parameter_name of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501


        :return: The parameter_name of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :rtype: str
        """
        return self._parameter_name

    @parameter_name.setter
    def parameter_name(self, parameter_name):
        """Sets the parameter_name of this ParameterForDescribeDBInstanceParametersOutput.


        :param parameter_name: The parameter_name of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :type: str
        """

        self._parameter_name = parameter_name

    @property
    def parameter_value(self):
        """Gets the parameter_value of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501


        :return: The parameter_value of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :rtype: str
        """
        return self._parameter_value

    @parameter_value.setter
    def parameter_value(self, parameter_value):
        """Sets the parameter_value of this ParameterForDescribeDBInstanceParametersOutput.


        :param parameter_value: The parameter_value of this ParameterForDescribeDBInstanceParametersOutput.  # noqa: E501
        :type: str
        """

        self._parameter_value = parameter_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ParameterForDescribeDBInstanceParametersOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ParameterForDescribeDBInstanceParametersOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ParameterForDescribeDBInstanceParametersOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    clb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeListenerAttributesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'acl_ids': 'list[str]',
        'acl_status': 'str',
        'acl_type': 'str',
        'certificate_id': 'str',
        'create_time': 'str',
        'description': 'str',
        'enabled': 'str',
        'established_timeout': 'int',
        'health_check': 'HealthCheckForDescribeListenerAttributesOutput',
        'listener_id': 'str',
        'listener_name': 'str',
        'load_balancer_id': 'str',
        'port': 'int',
        'protocol': 'str',
        'request_id': 'str',
        'scheduler': 'str',
        'server_group_id': 'str',
        'status': 'str',
        'update_time': 'str'
    }

    attribute_map = {
        'acl_ids': 'AclIds',
        'acl_status': 'AclStatus',
        'acl_type': 'AclType',
        'certificate_id': 'CertificateId',
        'create_time': 'CreateTime',
        'description': 'Description',
        'enabled': 'Enabled',
        'established_timeout': 'EstablishedTimeout',
        'health_check': 'HealthCheck',
        'listener_id': 'ListenerId',
        'listener_name': 'ListenerName',
        'load_balancer_id': 'LoadBalancerId',
        'port': 'Port',
        'protocol': 'Protocol',
        'request_id': 'RequestId',
        'scheduler': 'Scheduler',
        'server_group_id': 'ServerGroupId',
        'status': 'Status',
        'update_time': 'UpdateTime'
    }

    def __init__(self, acl_ids=None, acl_status=None, acl_type=None, certificate_id=None, create_time=None, description=None, enabled=None, established_timeout=None, health_check=None, listener_id=None, listener_name=None, load_balancer_id=None, port=None, protocol=None, request_id=None, scheduler=None, server_group_id=None, status=None, update_time=None, _configuration=None):  # noqa: E501
        """DescribeListenerAttributesResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._acl_ids = None
        self._acl_status = None
        self._acl_type = None
        self._certificate_id = None
        self._create_time = None
        self._description = None
        self._enabled = None
        self._established_timeout = None
        self._health_check = None
        self._listener_id = None
        self._listener_name = None
        self._load_balancer_id = None
        self._port = None
        self._protocol = None
        self._request_id = None
        self._scheduler = None
        self._server_group_id = None
        self._status = None
        self._update_time = None
        self.discriminator = None

        if acl_ids is not None:
            self.acl_ids = acl_ids
        if acl_status is not None:
            self.acl_status = acl_status
        if acl_type is not None:
            self.acl_type = acl_type
        if certificate_id is not None:
            self.certificate_id = certificate_id
        if create_time is not None:
            self.create_time = create_time
        if description is not None:
            self.description = description
        if enabled is not None:
            self.enabled = enabled
        if established_timeout is not None:
            self.established_timeout = established_timeout
        if health_check is not None:
            self.health_check = health_check
        if listener_id is not None:
            self.listener_id = listener_id
        if listener_name is not None:
            self.listener_name = listener_name
        if load_balancer_id is not None:
            self.load_balancer_id = load_balancer_id
        if port is not None:
            self.port = port
        if protocol is not None:
            self.protocol = protocol
        if request_id is not None:
            self.request_id = request_id
        if scheduler is not None:
            self.scheduler = scheduler
        if server_group_id is not None:
            self.server_group_id = server_group_id
        if status is not None:
            self.status = status
        if update_time is not None:
            self.update_time = update_time

    @property
    def acl_ids(self):
        """Gets the acl_ids of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The acl_ids of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl_ids

    @acl_ids.setter
    def acl_ids(self, acl_ids):
        """Sets the acl_ids of this DescribeListenerAttributesResponse.


        :param acl_ids: The acl_ids of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: list[str]
        """

        self._acl_ids = acl_ids

    @property
    def acl_status(self):
        """Gets the acl_status of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The acl_status of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._acl_status

    @acl_status.setter
    def acl_status(self, acl_status):
        """Sets the acl_status of this DescribeListenerAttributesResponse.


        :param acl_status: The acl_status of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._acl_status = acl_status

    @property
    def acl_type(self):
        """Gets the acl_type of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The acl_type of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._acl_type

    @acl_type.setter
    def acl_type(self, acl_type):
        """Sets the acl_type of this DescribeListenerAttributesResponse.


        :param acl_type: The acl_type of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._acl_type = acl_type

    @property
    def certificate_id(self):
        """Gets the certificate_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The certificate_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._certificate_id

    @certificate_id.setter
    def certificate_id(self, certificate_id):
        """Sets the certificate_id of this DescribeListenerAttributesResponse.


        :param certificate_id: The certificate_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._certificate_id = certificate_id

    @property
    def create_time(self):
        """Gets the create_time of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The create_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this DescribeListenerAttributesResponse.


        :param create_time: The create_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def description(self):
        """Gets the description of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The description of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DescribeListenerAttributesResponse.


        :param description: The description of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def enabled(self):
        """Gets the enabled of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The enabled of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DescribeListenerAttributesResponse.


        :param enabled: The enabled of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def established_timeout(self):
        """Gets the established_timeout of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The established_timeout of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: int
        """
        return self._established_timeout

    @established_timeout.setter
    def established_timeout(self, established_timeout):
        """Sets the established_timeout of this DescribeListenerAttributesResponse.


        :param established_timeout: The established_timeout of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: int
        """

        self._established_timeout = established_timeout

    @property
    def health_check(self):
        """Gets the health_check of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The health_check of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: HealthCheckForDescribeListenerAttributesOutput
        """
        return self._health_check

    @health_check.setter
    def health_check(self, health_check):
        """Sets the health_check of this DescribeListenerAttributesResponse.


        :param health_check: The health_check of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: HealthCheckForDescribeListenerAttributesOutput
        """

        self._health_check = health_check

    @property
    def listener_id(self):
        """Gets the listener_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The listener_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._listener_id

    @listener_id.setter
    def listener_id(self, listener_id):
        """Sets the listener_id of this DescribeListenerAttributesResponse.


        :param listener_id: The listener_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._listener_id = listener_id

    @property
    def listener_name(self):
        """Gets the listener_name of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The listener_name of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._listener_name

    @listener_name.setter
    def listener_name(self, listener_name):
        """Sets the listener_name of this DescribeListenerAttributesResponse.


        :param listener_name: The listener_name of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._listener_name = listener_name

    @property
    def load_balancer_id(self):
        """Gets the load_balancer_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The load_balancer_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._load_balancer_id

    @load_balancer_id.setter
    def load_balancer_id(self, load_balancer_id):
        """Sets the load_balancer_id of this DescribeListenerAttributesResponse.


        :param load_balancer_id: The load_balancer_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._load_balancer_id = load_balancer_id

    @property
    def port(self):
        """Gets the port of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The port of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this DescribeListenerAttributesResponse.


        :param port: The port of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def protocol(self):
        """Gets the protocol of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The protocol of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this DescribeListenerAttributesResponse.


        :param protocol: The protocol of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def request_id(self):
        """Gets the request_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The request_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DescribeListenerAttributesResponse.


        :param request_id: The request_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def scheduler(self):
        """Gets the scheduler of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The scheduler of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._scheduler

    @scheduler.setter
    def scheduler(self, scheduler):
        """Sets the scheduler of this DescribeListenerAttributesResponse.


        :param scheduler: The scheduler of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._scheduler = scheduler

    @property
    def server_group_id(self):
        """Gets the server_group_id of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The server_group_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._server_group_id

    @server_group_id.setter
    def server_group_id(self, server_group_id):
        """Sets the server_group_id of this DescribeListenerAttributesResponse.


        :param server_group_id: The server_group_id of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._server_group_id = server_group_id

    @property
    def status(self):
        """Gets the status of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The status of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeListenerAttributesResponse.


        :param status: The status of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def update_time(self):
        """Gets the update_time of this DescribeListenerAttributesResponse.  # noqa: E501


        :return: The update_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this DescribeListenerAttributesResponse.


        :param update_time: The update_time of this DescribeListenerAttributesResponse.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeListenerAttributesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeListenerAttributesResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeListenerAttributesResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class SecurityGroupForDescribeSecurityGroupsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'creation_time': 'str',
        'description': 'str',
        'project_name': 'str',
        'security_group_id': 'str',
        'security_group_name': 'str',
        'status': 'str',
        'tags': 'list[TagForDescribeSecurityGroupsOutput]',
        'type': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'creation_time': 'CreationTime',
        'description': 'Description',
        'project_name': 'ProjectName',
        'security_group_id': 'SecurityGroupId',
        'security_group_name': 'SecurityGroupName',
        'status': 'Status',
        'tags': 'Tags',
        'type': 'Type',
        'vpc_id': 'VpcId'
    }

    def __init__(self, creation_time=None, description=None, project_name=None, security_group_id=None, security_group_name=None, status=None, tags=None, type=None, vpc_id=None, _configuration=None):  # noqa: E501
        """SecurityGroupForDescribeSecurityGroupsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._creation_time = None
        self._description = None
        self._project_name = None
        self._security_group_id = None
        self._security_group_name = None
        self._status = None
        self._tags = None
        self._type = None
        self._vpc_id = None
        self.discriminator = None

        if creation_time is not None:
            self.creation_time = creation_time
        if description is not None:
            self.description = description
        if project_name is not None:
            self.project_name = project_name
        if security_group_id is not None:
            self.security_group_id = security_group_id
        if security_group_name is not None:
            self.security_group_name = security_group_name
        if status is not None:
            self.status = status
        if tags is not None:
            self.tags = tags
        if type is not None:
            self.type = type
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def creation_time(self):
        """Gets the creation_time of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The creation_time of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param creation_time: The creation_time of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def description(self):
        """Gets the description of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The description of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param description: The description of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def project_name(self):
        """Gets the project_name of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The project_name of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param project_name: The project_name of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def security_group_id(self):
        """Gets the security_group_id of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The security_group_id of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._security_group_id

    @security_group_id.setter
    def security_group_id(self, security_group_id):
        """Sets the security_group_id of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param security_group_id: The security_group_id of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._security_group_id = security_group_id

    @property
    def security_group_name(self):
        """Gets the security_group_name of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The security_group_name of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._security_group_name

    @security_group_name.setter
    def security_group_name(self, security_group_name):
        """Sets the security_group_name of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param security_group_name: The security_group_name of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._security_group_name = security_group_name

    @property
    def status(self):
        """Gets the status of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The status of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param status: The status of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def tags(self):
        """Gets the tags of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The tags of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: list[TagForDescribeSecurityGroupsOutput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param tags: The tags of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: list[TagForDescribeSecurityGroupsOutput]
        """

        self._tags = tags

    @property
    def type(self):
        """Gets the type of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The type of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param type: The type of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def vpc_id(self):
        """Gets the vpc_id of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501


        :return: The vpc_id of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this SecurityGroupForDescribeSecurityGroupsOutput.


        :param vpc_id: The vpc_id of this SecurityGroupForDescribeSecurityGroupsOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SecurityGroupForDescribeSecurityGroupsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityGroupForDescribeSecurityGroupsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SecurityGroupForDescribeSecurityGroupsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ModifyDBInstanceNodeNumberRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'apply_immediately': 'bool',
        'client_token': 'str',
        'create_backup': 'bool',
        'instance_id': 'str',
        'node_number': 'int'
    }

    attribute_map = {
        'apply_immediately': 'ApplyImmediately',
        'client_token': 'ClientToken',
        'create_backup': 'CreateBackup',
        'instance_id': 'InstanceId',
        'node_number': 'NodeNumber'
    }

    def __init__(self, apply_immediately=None, client_token=None, create_backup=None, instance_id=None, node_number=None, _configuration=None):  # noqa: E501
        """ModifyDBInstanceNodeNumberRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._apply_immediately = None
        self._client_token = None
        self._create_backup = None
        self._instance_id = None
        self._node_number = None
        self.discriminator = None

        self.apply_immediately = apply_immediately
        if client_token is not None:
            self.client_token = client_token
        if create_backup is not None:
            self.create_backup = create_backup
        self.instance_id = instance_id
        self.node_number = node_number

    @property
    def apply_immediately(self):
        """Gets the apply_immediately of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501


        :return: The apply_immediately of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :rtype: bool
        """
        return self._apply_immediately

    @apply_immediately.setter
    def apply_immediately(self, apply_immediately):
        """Sets the apply_immediately of this ModifyDBInstanceNodeNumberRequest.


        :param apply_immediately: The apply_immediately of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and apply_immediately is None:
            raise ValueError("Invalid value for `apply_immediately`, must not be `None`")  # noqa: E501

        self._apply_immediately = apply_immediately

    @property
    def client_token(self):
        """Gets the client_token of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501


        :return: The client_token of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_token

    @client_token.setter
    def client_token(self, client_token):
        """Sets the client_token of this ModifyDBInstanceNodeNumberRequest.


        :param client_token: The client_token of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :type: str
        """

        self._client_token = client_token

    @property
    def create_backup(self):
        """Gets the create_backup of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501


        :return: The create_backup of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :rtype: bool
        """
        return self._create_backup

    @create_backup.setter
    def create_backup(self, create_backup):
        """Sets the create_backup of this ModifyDBInstanceNodeNumberRequest.


        :param create_backup: The create_backup of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :type: bool
        """

        self._create_backup = create_backup

    @property
    def instance_id(self):
        """Gets the instance_id of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501


        :return: The instance_id of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ModifyDBInstanceNodeNumberRequest.


        :param instance_id: The instance_id of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def node_number(self):
        """Gets the node_number of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501


        :return: The node_number of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :rtype: int
        """
        return self._node_number

    @node_number.setter
    def node_number(self, node_number):
        """Sets the node_number of this ModifyDBInstanceNodeNumberRequest.


        :param node_number: The node_number of this ModifyDBInstanceNodeNumberRequest.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and node_number is None:
            raise ValueError("Invalid value for `node_number`, must not be `None`")  # noqa: E501

        self._node_number = node_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModifyDBInstanceNodeNumberRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyDBInstanceNodeNumberRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModifyDBInstanceNodeNumberRequest):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import print_function
import volcenginesdkcore
import volcenginesdkvpc
from pprint import pprint

if __name__ == '__main__':
    configuration = volcenginesdkcore.Configuration()
    configuration.ak = "XX"
    configuration.sk = "XX"
    configuration.region = "XX"

    # create an instance of the API class
    api_instance = volcenginesdkvpc.VPCApi(volcenginesdkcore.ApiClient(configuration))
    body = volcenginesdkvpc.DescribeEipAddressesRequest(
        allocation_ids=["eip-2feuho4efrbb45om1w86", "eip-1g0vtlyo1huyox2zmjaw"])
    api_response = api_instance.describe_eip_addresses(body)
    pprint(api_response)



# coding: utf-8

"""
    natgateway

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DescribeNatGatewayAttributesResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'billing_type': 'int',
        'business_status': 'str',
        'creation_time': 'str',
        'deleted_time': 'str',
        'description': 'str',
        'eip_addresses': 'list[EipAddressForDescribeNatGatewayAttributesOutput]',
        'expired_time': 'str',
        'lock_reason': 'str',
        'nat_gateway_id': 'str',
        'nat_gateway_name': 'str',
        'network_interface_id': 'str',
        'overdue_time': 'str',
        'project_name': 'str',
        'request_id': 'str',
        'spec': 'str',
        'status': 'str',
        'subnet_id': 'str',
        'tags': 'list[TagForDescribeNatGatewayAttributesOutput]',
        'updated_at': 'str',
        'vpc_id': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'billing_type': 'BillingType',
        'business_status': 'BusinessStatus',
        'creation_time': 'CreationTime',
        'deleted_time': 'DeletedTime',
        'description': 'Description',
        'eip_addresses': 'EipAddresses',
        'expired_time': 'ExpiredTime',
        'lock_reason': 'LockReason',
        'nat_gateway_id': 'NatGatewayId',
        'nat_gateway_name': 'NatGatewayName',
        'network_interface_id': 'NetworkInterfaceId',
        'overdue_time': 'OverdueTime',
        'project_name': 'ProjectName',
        'request_id': 'RequestId',
        'spec': 'Spec',
        'status': 'Status',
        'subnet_id': 'SubnetId',
        'tags': 'Tags',
        'updated_at': 'UpdatedAt',
        'vpc_id': 'VpcId',
        'zone_id': 'ZoneId'
    }

    def __init__(self, billing_type=None, business_status=None, creation_time=None, deleted_time=None, description=None, eip_addresses=None, expired_time=None, lock_reason=None, nat_gateway_id=None, nat_gateway_name=None, network_interface_id=None, overdue_time=None, project_name=None, request_id=None, spec=None, status=None, subnet_id=None, tags=None, updated_at=None, vpc_id=None, zone_id=None, _configuration=None):  # noqa: E501
        """DescribeNatGatewayAttributesResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._billing_type = None
        self._business_status = None
        self._creation_time = None
        self._deleted_time = None
        self._description = None
        self._eip_addresses = None
        self._expired_time = None
        self._lock_reason = None
        self._nat_gateway_id = None
        self._nat_gateway_name = None
        self._network_interface_id = None
        self._overdue_time = None
        self._project_name = None
        self._request_id = None
        self._spec = None
        self._status = None
        self._subnet_id = None
        self._tags = None
        self._updated_at = None
        self._vpc_id = None
        self._zone_id = None
        self.discriminator = None

        if billing_type is not None:
            self.billing_type = billing_type
        if business_status is not None:
            self.business_status = business_status
        if creation_time is not None:
            self.creation_time = creation_time
        if deleted_time is not None:
            self.deleted_time = deleted_time
        if description is not None:
            self.description = description
        if eip_addresses is not None:
            self.eip_addresses = eip_addresses
        if expired_time is not None:
            self.expired_time = expired_time
        if lock_reason is not None:
            self.lock_reason = lock_reason
        if nat_gateway_id is not None:
            self.nat_gateway_id = nat_gateway_id
        if nat_gateway_name is not None:
            self.nat_gateway_name = nat_gateway_name
        if network_interface_id is not None:
            self.network_interface_id = network_interface_id
        if overdue_time is not None:
            self.overdue_time = overdue_time
        if project_name is not None:
            self.project_name = project_name
        if request_id is not None:
            self.request_id = request_id
        if spec is not None:
            self.spec = spec
        if status is not None:
            self.status = status
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if tags is not None:
            self.tags = tags
        if updated_at is not None:
            self.updated_at = updated_at
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def billing_type(self):
        """Gets the billing_type of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The billing_type of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: int
        """
        return self._billing_type

    @billing_type.setter
    def billing_type(self, billing_type):
        """Sets the billing_type of this DescribeNatGatewayAttributesResponse.


        :param billing_type: The billing_type of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: int
        """

        self._billing_type = billing_type

    @property
    def business_status(self):
        """Gets the business_status of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The business_status of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._business_status

    @business_status.setter
    def business_status(self, business_status):
        """Sets the business_status of this DescribeNatGatewayAttributesResponse.


        :param business_status: The business_status of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._business_status = business_status

    @property
    def creation_time(self):
        """Gets the creation_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The creation_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this DescribeNatGatewayAttributesResponse.


        :param creation_time: The creation_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._creation_time = creation_time

    @property
    def deleted_time(self):
        """Gets the deleted_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The deleted_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._deleted_time

    @deleted_time.setter
    def deleted_time(self, deleted_time):
        """Sets the deleted_time of this DescribeNatGatewayAttributesResponse.


        :param deleted_time: The deleted_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._deleted_time = deleted_time

    @property
    def description(self):
        """Gets the description of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The description of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DescribeNatGatewayAttributesResponse.


        :param description: The description of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def eip_addresses(self):
        """Gets the eip_addresses of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The eip_addresses of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: list[EipAddressForDescribeNatGatewayAttributesOutput]
        """
        return self._eip_addresses

    @eip_addresses.setter
    def eip_addresses(self, eip_addresses):
        """Sets the eip_addresses of this DescribeNatGatewayAttributesResponse.


        :param eip_addresses: The eip_addresses of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: list[EipAddressForDescribeNatGatewayAttributesOutput]
        """

        self._eip_addresses = eip_addresses

    @property
    def expired_time(self):
        """Gets the expired_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The expired_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._expired_time

    @expired_time.setter
    def expired_time(self, expired_time):
        """Sets the expired_time of this DescribeNatGatewayAttributesResponse.


        :param expired_time: The expired_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._expired_time = expired_time

    @property
    def lock_reason(self):
        """Gets the lock_reason of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The lock_reason of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._lock_reason

    @lock_reason.setter
    def lock_reason(self, lock_reason):
        """Sets the lock_reason of this DescribeNatGatewayAttributesResponse.


        :param lock_reason: The lock_reason of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._lock_reason = lock_reason

    @property
    def nat_gateway_id(self):
        """Gets the nat_gateway_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The nat_gateway_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._nat_gateway_id

    @nat_gateway_id.setter
    def nat_gateway_id(self, nat_gateway_id):
        """Sets the nat_gateway_id of this DescribeNatGatewayAttributesResponse.


        :param nat_gateway_id: The nat_gateway_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._nat_gateway_id = nat_gateway_id

    @property
    def nat_gateway_name(self):
        """Gets the nat_gateway_name of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The nat_gateway_name of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._nat_gateway_name

    @nat_gateway_name.setter
    def nat_gateway_name(self, nat_gateway_name):
        """Sets the nat_gateway_name of this DescribeNatGatewayAttributesResponse.


        :param nat_gateway_name: The nat_gateway_name of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._nat_gateway_name = nat_gateway_name

    @property
    def network_interface_id(self):
        """Gets the network_interface_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The network_interface_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._network_interface_id

    @network_interface_id.setter
    def network_interface_id(self, network_interface_id):
        """Sets the network_interface_id of this DescribeNatGatewayAttributesResponse.


        :param network_interface_id: The network_interface_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._network_interface_id = network_interface_id

    @property
    def overdue_time(self):
        """Gets the overdue_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The overdue_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._overdue_time

    @overdue_time.setter
    def overdue_time(self, overdue_time):
        """Sets the overdue_time of this DescribeNatGatewayAttributesResponse.


        :param overdue_time: The overdue_time of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._overdue_time = overdue_time

    @property
    def project_name(self):
        """Gets the project_name of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The project_name of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DescribeNatGatewayAttributesResponse.


        :param project_name: The project_name of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def request_id(self):
        """Gets the request_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The request_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this DescribeNatGatewayAttributesResponse.


        :param request_id: The request_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def spec(self):
        """Gets the spec of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The spec of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this DescribeNatGatewayAttributesResponse.


        :param spec: The spec of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._spec = spec

    @property
    def status(self):
        """Gets the status of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The status of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DescribeNatGatewayAttributesResponse.


        :param status: The status of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def subnet_id(self):
        """Gets the subnet_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The subnet_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this DescribeNatGatewayAttributesResponse.


        :param subnet_id: The subnet_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def tags(self):
        """Gets the tags of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The tags of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: list[TagForDescribeNatGatewayAttributesOutput]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this DescribeNatGatewayAttributesResponse.


        :param tags: The tags of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: list[TagForDescribeNatGatewayAttributesOutput]
        """

        self._tags = tags

    @property
    def updated_at(self):
        """Gets the updated_at of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The updated_at of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DescribeNatGatewayAttributesResponse.


        :param updated_at: The updated_at of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def vpc_id(self):
        """Gets the vpc_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The vpc_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this DescribeNatGatewayAttributesResponse.


        :param vpc_id: The vpc_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone_id(self):
        """Gets the zone_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501


        :return: The zone_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this DescribeNatGatewayAttributesResponse.


        :param zone_id: The zone_id of this DescribeNatGatewayAttributesResponse.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DescribeNatGatewayAttributesResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DescribeNatGatewayAttributesResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DescribeNatGatewayAttributesResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    mongodb

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DBInstanceForDescribeDBInstancesOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auto_renew': 'bool',
        'charge_status': 'str',
        'charge_type': 'str',
        'closed_time': 'str',
        'config_servers_id': 'str',
        'create_time': 'str',
        'db_engine': 'str',
        'db_engine_version': 'str',
        'db_engine_version_str': 'str',
        'expired_time': 'str',
        'instance_id': 'str',
        'instance_name': 'str',
        'instance_status': 'str',
        'instance_type': 'str',
        'mongos_id': 'str',
        'project_name': 'str',
        'reclaim_time': 'str',
        'subnet_id': 'str',
        'update_time': 'str',
        'vpc_id': 'str',
        'zone_id': 'str'
    }

    attribute_map = {
        'auto_renew': 'AutoRenew',
        'charge_status': 'ChargeStatus',
        'charge_type': 'ChargeType',
        'closed_time': 'ClosedTime',
        'config_servers_id': 'ConfigServersId',
        'create_time': 'CreateTime',
        'db_engine': 'DBEngine',
        'db_engine_version': 'DBEngineVersion',
        'db_engine_version_str': 'DBEngineVersionStr',
        'expired_time': 'ExpiredTime',
        'instance_id': 'InstanceId',
        'instance_name': 'InstanceName',
        'instance_status': 'InstanceStatus',
        'instance_type': 'InstanceType',
        'mongos_id': 'MongosId',
        'project_name': 'ProjectName',
        'reclaim_time': 'ReclaimTime',
        'subnet_id': 'SubnetId',
        'update_time': 'UpdateTime',
        'vpc_id': 'VpcId',
        'zone_id': 'ZoneId'
    }

    def __init__(self, auto_renew=None, charge_status=None, charge_type=None, closed_time=None, config_servers_id=None, create_time=None, db_engine=None, db_engine_version=None, db_engine_version_str=None, expired_time=None, instance_id=None, instance_name=None, instance_status=None, instance_type=None, mongos_id=None, project_name=None, reclaim_time=None, subnet_id=None, update_time=None, vpc_id=None, zone_id=None, _configuration=None):  # noqa: E501
        """DBInstanceForDescribeDBInstancesOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auto_renew = None
        self._charge_status = None
        self._charge_type = None
        self._closed_time = None
        self._config_servers_id = None
        self._create_time = None
        self._db_engine = None
        self._db_engine_version = None
        self._db_engine_version_str = None
        self._expired_time = None
        self._instance_id = None
        self._instance_name = None
        self._instance_status = None
        self._instance_type = None
        self._mongos_id = None
        self._project_name = None
        self._reclaim_time = None
        self._subnet_id = None
        self._update_time = None
        self._vpc_id = None
        self._zone_id = None
        self.discriminator = None

        if auto_renew is not None:
            self.auto_renew = auto_renew
        if charge_status is not None:
            self.charge_status = charge_status
        if charge_type is not None:
            self.charge_type = charge_type
        if closed_time is not None:
            self.closed_time = closed_time
        if config_servers_id is not None:
            self.config_servers_id = config_servers_id
        if create_time is not None:
            self.create_time = create_time
        if db_engine is not None:
            self.db_engine = db_engine
        if db_engine_version is not None:
            self.db_engine_version = db_engine_version
        if db_engine_version_str is not None:
            self.db_engine_version_str = db_engine_version_str
        if expired_time is not None:
            self.expired_time = expired_time
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_name is not None:
            self.instance_name = instance_name
        if instance_status is not None:
            self.instance_status = instance_status
        if instance_type is not None:
            self.instance_type = instance_type
        if mongos_id is not None:
            self.mongos_id = mongos_id
        if project_name is not None:
            self.project_name = project_name
        if reclaim_time is not None:
            self.reclaim_time = reclaim_time
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if update_time is not None:
            self.update_time = update_time
        if vpc_id is not None:
            self.vpc_id = vpc_id
        if zone_id is not None:
            self.zone_id = zone_id

    @property
    def auto_renew(self):
        """Gets the auto_renew of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The auto_renew of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this DBInstanceForDescribeDBInstancesOutput.


        :param auto_renew: The auto_renew of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: bool
        """

        self._auto_renew = auto_renew

    @property
    def charge_status(self):
        """Gets the charge_status of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The charge_status of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._charge_status

    @charge_status.setter
    def charge_status(self, charge_status):
        """Sets the charge_status of this DBInstanceForDescribeDBInstancesOutput.


        :param charge_status: The charge_status of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._charge_status = charge_status

    @property
    def charge_type(self):
        """Gets the charge_type of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The charge_type of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """Sets the charge_type of this DBInstanceForDescribeDBInstancesOutput.


        :param charge_type: The charge_type of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._charge_type = charge_type

    @property
    def closed_time(self):
        """Gets the closed_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The closed_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._closed_time

    @closed_time.setter
    def closed_time(self, closed_time):
        """Sets the closed_time of this DBInstanceForDescribeDBInstancesOutput.


        :param closed_time: The closed_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._closed_time = closed_time

    @property
    def config_servers_id(self):
        """Gets the config_servers_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The config_servers_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._config_servers_id

    @config_servers_id.setter
    def config_servers_id(self, config_servers_id):
        """Sets the config_servers_id of this DBInstanceForDescribeDBInstancesOutput.


        :param config_servers_id: The config_servers_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._config_servers_id = config_servers_id

    @property
    def create_time(self):
        """Gets the create_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The create_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this DBInstanceForDescribeDBInstancesOutput.


        :param create_time: The create_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def db_engine(self):
        """Gets the db_engine of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The db_engine of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_engine

    @db_engine.setter
    def db_engine(self, db_engine):
        """Sets the db_engine of this DBInstanceForDescribeDBInstancesOutput.


        :param db_engine: The db_engine of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._db_engine = db_engine

    @property
    def db_engine_version(self):
        """Gets the db_engine_version of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The db_engine_version of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version

    @db_engine_version.setter
    def db_engine_version(self, db_engine_version):
        """Sets the db_engine_version of this DBInstanceForDescribeDBInstancesOutput.


        :param db_engine_version: The db_engine_version of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._db_engine_version = db_engine_version

    @property
    def db_engine_version_str(self):
        """Gets the db_engine_version_str of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The db_engine_version_str of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._db_engine_version_str

    @db_engine_version_str.setter
    def db_engine_version_str(self, db_engine_version_str):
        """Sets the db_engine_version_str of this DBInstanceForDescribeDBInstancesOutput.


        :param db_engine_version_str: The db_engine_version_str of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._db_engine_version_str = db_engine_version_str

    @property
    def expired_time(self):
        """Gets the expired_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The expired_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._expired_time

    @expired_time.setter
    def expired_time(self, expired_time):
        """Sets the expired_time of this DBInstanceForDescribeDBInstancesOutput.


        :param expired_time: The expired_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._expired_time = expired_time

    @property
    def instance_id(self):
        """Gets the instance_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The instance_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DBInstanceForDescribeDBInstancesOutput.


        :param instance_id: The instance_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_name(self):
        """Gets the instance_name of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The instance_name of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this DBInstanceForDescribeDBInstancesOutput.


        :param instance_name: The instance_name of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_name = instance_name

    @property
    def instance_status(self):
        """Gets the instance_status of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The instance_status of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_status

    @instance_status.setter
    def instance_status(self, instance_status):
        """Sets the instance_status of this DBInstanceForDescribeDBInstancesOutput.


        :param instance_status: The instance_status of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_status = instance_status

    @property
    def instance_type(self):
        """Gets the instance_type of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The instance_type of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this DBInstanceForDescribeDBInstancesOutput.


        :param instance_type: The instance_type of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def mongos_id(self):
        """Gets the mongos_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The mongos_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._mongos_id

    @mongos_id.setter
    def mongos_id(self, mongos_id):
        """Sets the mongos_id of this DBInstanceForDescribeDBInstancesOutput.


        :param mongos_id: The mongos_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._mongos_id = mongos_id

    @property
    def project_name(self):
        """Gets the project_name of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The project_name of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this DBInstanceForDescribeDBInstancesOutput.


        :param project_name: The project_name of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._project_name = project_name

    @property
    def reclaim_time(self):
        """Gets the reclaim_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The reclaim_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._reclaim_time

    @reclaim_time.setter
    def reclaim_time(self, reclaim_time):
        """Sets the reclaim_time of this DBInstanceForDescribeDBInstancesOutput.


        :param reclaim_time: The reclaim_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._reclaim_time = reclaim_time

    @property
    def subnet_id(self):
        """Gets the subnet_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The subnet_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this DBInstanceForDescribeDBInstancesOutput.


        :param subnet_id: The subnet_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def update_time(self):
        """Gets the update_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The update_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this DBInstanceForDescribeDBInstancesOutput.


        :param update_time: The update_time of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._update_time = update_time

    @property
    def vpc_id(self):
        """Gets the vpc_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The vpc_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this DBInstanceForDescribeDBInstancesOutput.


        :param vpc_id: The vpc_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    @property
    def zone_id(self):
        """Gets the zone_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501


        :return: The zone_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this DBInstanceForDescribeDBInstancesOutput.


        :param zone_id: The zone_id of this DBInstanceForDescribeDBInstancesOutput.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DBInstanceForDescribeDBInstancesOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DBInstanceForDescribeDBInstancesOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DBInstanceForDescribeDBInstancesOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    ecs

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class DeploymentSetForDescribeDeploymentSetsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capacities': 'list[CapacityForDescribeDeploymentSetsOutput]',
        'created_at': 'str',
        'deployment_set_description': 'str',
        'deployment_set_id': 'str',
        'deployment_set_name': 'str',
        'granularity': 'str',
        'instance_amount': 'int',
        'instance_ids': 'list[str]',
        'strategy': 'str'
    }

    attribute_map = {
        'capacities': 'Capacities',
        'created_at': 'CreatedAt',
        'deployment_set_description': 'DeploymentSetDescription',
        'deployment_set_id': 'DeploymentSetId',
        'deployment_set_name': 'DeploymentSetName',
        'granularity': 'Granularity',
        'instance_amount': 'InstanceAmount',
        'instance_ids': 'InstanceIds',
        'strategy': 'Strategy'
    }

    def __init__(self, capacities=None, created_at=None, deployment_set_description=None, deployment_set_id=None, deployment_set_name=None, granularity=None, instance_amount=None, instance_ids=None, strategy=None, _configuration=None):  # noqa: E501
        """DeploymentSetForDescribeDeploymentSetsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._capacities = None
        self._created_at = None
        self._deployment_set_description = None
        self._deployment_set_id = None
        self._deployment_set_name = None
        self._granularity = None
        self._instance_amount = None
        self._instance_ids = None
        self._strategy = None
        self.discriminator = None

        if capacities is not None:
            self.capacities = capacities
        if created_at is not None:
            self.created_at = created_at
        if deployment_set_description is not None:
            self.deployment_set_description = deployment_set_description
        if deployment_set_id is not None:
            self.deployment_set_id = deployment_set_id
        if deployment_set_name is not None:
            self.deployment_set_name = deployment_set_name
        if granularity is not None:
            self.granularity = granularity
        if instance_amount is not None:
            self.instance_amount = instance_amount
        if instance_ids is not None:
            self.instance_ids = instance_ids
        if strategy is not None:
            self.strategy = strategy

    @property
    def capacities(self):
        """Gets the capacities of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The capacities of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: list[CapacityForDescribeDeploymentSetsOutput]
        """
        return self._capacities

    @capacities.setter
    def capacities(self, capacities):
        """Sets the capacities of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param capacities: The capacities of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: list[CapacityForDescribeDeploymentSetsOutput]
        """

        self._capacities = capacities

    @property
    def created_at(self):
        """Gets the created_at of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The created_at of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param created_at: The created_at of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def deployment_set_description(self):
        """Gets the deployment_set_description of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The deployment_set_description of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: str
        """
        return self._deployment_set_description

    @deployment_set_description.setter
    def deployment_set_description(self, deployment_set_description):
        """Sets the deployment_set_description of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param deployment_set_description: The deployment_set_description of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: str
        """

        self._deployment_set_description = deployment_set_description

    @property
    def deployment_set_id(self):
        """Gets the deployment_set_id of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The deployment_set_id of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: str
        """
        return self._deployment_set_id

    @deployment_set_id.setter
    def deployment_set_id(self, deployment_set_id):
        """Sets the deployment_set_id of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param deployment_set_id: The deployment_set_id of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: str
        """

        self._deployment_set_id = deployment_set_id

    @property
    def deployment_set_name(self):
        """Gets the deployment_set_name of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The deployment_set_name of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: str
        """
        return self._deployment_set_name

    @deployment_set_name.setter
    def deployment_set_name(self, deployment_set_name):
        """Sets the deployment_set_name of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param deployment_set_name: The deployment_set_name of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: str
        """

        self._deployment_set_name = deployment_set_name

    @property
    def granularity(self):
        """Gets the granularity of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The granularity of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: str
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """Sets the granularity of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param granularity: The granularity of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: str
        """

        self._granularity = granularity

    @property
    def instance_amount(self):
        """Gets the instance_amount of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The instance_amount of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: int
        """
        return self._instance_amount

    @instance_amount.setter
    def instance_amount(self, instance_amount):
        """Sets the instance_amount of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param instance_amount: The instance_amount of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: int
        """

        self._instance_amount = instance_amount

    @property
    def instance_ids(self):
        """Gets the instance_ids of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The instance_ids of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._instance_ids

    @instance_ids.setter
    def instance_ids(self, instance_ids):
        """Sets the instance_ids of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param instance_ids: The instance_ids of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: list[str]
        """

        self._instance_ids = instance_ids

    @property
    def strategy(self):
        """Gets the strategy of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501


        :return: The strategy of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :rtype: str
        """
        return self._strategy

    @strategy.setter
    def strategy(self, strategy):
        """Sets the strategy of this DeploymentSetForDescribeDeploymentSetsOutput.


        :param strategy: The strategy of this DeploymentSetForDescribeDeploymentSetsOutput.  # noqa: E501
        :type: str
        """

        self._strategy = strategy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeploymentSetForDescribeDeploymentSetsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeploymentSetForDescribeDeploymentSetsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeploymentSetForDescribeDeploymentSetsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class VisitAddrForDescribeDBInstanceDetailOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'addr_type': 'str',
        'address': 'str',
        'eip_id': 'str',
        'port': 'str'
    }

    attribute_map = {
        'addr_type': 'AddrType',
        'address': 'Address',
        'eip_id': 'EipId',
        'port': 'Port'
    }

    def __init__(self, addr_type=None, address=None, eip_id=None, port=None, _configuration=None):  # noqa: E501
        """VisitAddrForDescribeDBInstanceDetailOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._addr_type = None
        self._address = None
        self._eip_id = None
        self._port = None
        self.discriminator = None

        if addr_type is not None:
            self.addr_type = addr_type
        if address is not None:
            self.address = address
        if eip_id is not None:
            self.eip_id = eip_id
        if port is not None:
            self.port = port

    @property
    def addr_type(self):
        """Gets the addr_type of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The addr_type of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._addr_type

    @addr_type.setter
    def addr_type(self, addr_type):
        """Sets the addr_type of this VisitAddrForDescribeDBInstanceDetailOutput.


        :param addr_type: The addr_type of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._addr_type = addr_type

    @property
    def address(self):
        """Gets the address of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The address of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this VisitAddrForDescribeDBInstanceDetailOutput.


        :param address: The address of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def eip_id(self):
        """Gets the eip_id of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The eip_id of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._eip_id

    @eip_id.setter
    def eip_id(self, eip_id):
        """Sets the eip_id of this VisitAddrForDescribeDBInstanceDetailOutput.


        :param eip_id: The eip_id of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._eip_id = eip_id

    @property
    def port(self):
        """Gets the port of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501


        :return: The port of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this VisitAddrForDescribeDBInstanceDetailOutput.


        :param port: The port of this VisitAddrForDescribeDBInstanceDetailOutput.  # noqa: E501
        :type: str
        """

        self._port = port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VisitAddrForDescribeDBInstanceDetailOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VisitAddrForDescribeDBInstanceDetailOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VisitAddrForDescribeDBInstanceDetailOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    auto_scaling

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class ModifyScalingGroupRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active_scaling_configuration_id': 'str',
        'default_cooldown': 'int',
        'desire_instance_number': 'int',
        'instance_terminate_policy': 'str',
        'max_instance_number': 'int',
        'min_instance_number': 'int',
        'scaling_group_id': 'str',
        'scaling_group_name': 'str',
        'subnet_ids': 'list[str]'
    }

    attribute_map = {
        'active_scaling_configuration_id': 'ActiveScalingConfigurationId',
        'default_cooldown': 'DefaultCooldown',
        'desire_instance_number': 'DesireInstanceNumber',
        'instance_terminate_policy': 'InstanceTerminatePolicy',
        'max_instance_number': 'MaxInstanceNumber',
        'min_instance_number': 'MinInstanceNumber',
        'scaling_group_id': 'ScalingGroupId',
        'scaling_group_name': 'ScalingGroupName',
        'subnet_ids': 'SubnetIds'
    }

    def __init__(self, active_scaling_configuration_id=None, default_cooldown=None, desire_instance_number=None, instance_terminate_policy=None, max_instance_number=None, min_instance_number=None, scaling_group_id=None, scaling_group_name=None, subnet_ids=None, _configuration=None):  # noqa: E501
        """ModifyScalingGroupRequest - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active_scaling_configuration_id = None
        self._default_cooldown = None
        self._desire_instance_number = None
        self._instance_terminate_policy = None
        self._max_instance_number = None
        self._min_instance_number = None
        self._scaling_group_id = None
        self._scaling_group_name = None
        self._subnet_ids = None
        self.discriminator = None

        if active_scaling_configuration_id is not None:
            self.active_scaling_configuration_id = active_scaling_configuration_id
        if default_cooldown is not None:
            self.default_cooldown = default_cooldown
        if desire_instance_number is not None:
            self.desire_instance_number = desire_instance_number
        if instance_terminate_policy is not None:
            self.instance_terminate_policy = instance_terminate_policy
        if max_instance_number is not None:
            self.max_instance_number = max_instance_number
        if min_instance_number is not None:
            self.min_instance_number = min_instance_number
        if scaling_group_id is not None:
            self.scaling_group_id = scaling_group_id
        if scaling_group_name is not None:
            self.scaling_group_name = scaling_group_name
        if subnet_ids is not None:
            self.subnet_ids = subnet_ids

    @property
    def active_scaling_configuration_id(self):
        """Gets the active_scaling_configuration_id of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The active_scaling_configuration_id of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: str
        """
        return self._active_scaling_configuration_id

    @active_scaling_configuration_id.setter
    def active_scaling_configuration_id(self, active_scaling_configuration_id):
        """Sets the active_scaling_configuration_id of this ModifyScalingGroupRequest.


        :param active_scaling_configuration_id: The active_scaling_configuration_id of this ModifyScalingGroupRequest.  # noqa: E501
        :type: str
        """

        self._active_scaling_configuration_id = active_scaling_configuration_id

    @property
    def default_cooldown(self):
        """Gets the default_cooldown of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The default_cooldown of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: int
        """
        return self._default_cooldown

    @default_cooldown.setter
    def default_cooldown(self, default_cooldown):
        """Sets the default_cooldown of this ModifyScalingGroupRequest.


        :param default_cooldown: The default_cooldown of this ModifyScalingGroupRequest.  # noqa: E501
        :type: int
        """

        self._default_cooldown = default_cooldown

    @property
    def desire_instance_number(self):
        """Gets the desire_instance_number of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The desire_instance_number of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: int
        """
        return self._desire_instance_number

    @desire_instance_number.setter
    def desire_instance_number(self, desire_instance_number):
        """Sets the desire_instance_number of this ModifyScalingGroupRequest.


        :param desire_instance_number: The desire_instance_number of this ModifyScalingGroupRequest.  # noqa: E501
        :type: int
        """

        self._desire_instance_number = desire_instance_number

    @property
    def instance_terminate_policy(self):
        """Gets the instance_terminate_policy of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The instance_terminate_policy of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: str
        """
        return self._instance_terminate_policy

    @instance_terminate_policy.setter
    def instance_terminate_policy(self, instance_terminate_policy):
        """Sets the instance_terminate_policy of this ModifyScalingGroupRequest.


        :param instance_terminate_policy: The instance_terminate_policy of this ModifyScalingGroupRequest.  # noqa: E501
        :type: str
        """

        self._instance_terminate_policy = instance_terminate_policy

    @property
    def max_instance_number(self):
        """Gets the max_instance_number of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The max_instance_number of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: int
        """
        return self._max_instance_number

    @max_instance_number.setter
    def max_instance_number(self, max_instance_number):
        """Sets the max_instance_number of this ModifyScalingGroupRequest.


        :param max_instance_number: The max_instance_number of this ModifyScalingGroupRequest.  # noqa: E501
        :type: int
        """

        self._max_instance_number = max_instance_number

    @property
    def min_instance_number(self):
        """Gets the min_instance_number of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The min_instance_number of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: int
        """
        return self._min_instance_number

    @min_instance_number.setter
    def min_instance_number(self, min_instance_number):
        """Sets the min_instance_number of this ModifyScalingGroupRequest.


        :param min_instance_number: The min_instance_number of this ModifyScalingGroupRequest.  # noqa: E501
        :type: int
        """

        self._min_instance_number = min_instance_number

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The scaling_group_id of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this ModifyScalingGroupRequest.


        :param scaling_group_id: The scaling_group_id of this ModifyScalingGroupRequest.  # noqa: E501
        :type: str
        """

        self._scaling_group_id = scaling_group_id

    @property
    def scaling_group_name(self):
        """Gets the scaling_group_name of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The scaling_group_name of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: str
        """
        return self._scaling_group_name

    @scaling_group_name.setter
    def scaling_group_name(self, scaling_group_name):
        """Sets the scaling_group_name of this ModifyScalingGroupRequest.


        :param scaling_group_name: The scaling_group_name of this ModifyScalingGroupRequest.  # noqa: E501
        :type: str
        """

        self._scaling_group_name = scaling_group_name

    @property
    def subnet_ids(self):
        """Gets the subnet_ids of this ModifyScalingGroupRequest.  # noqa: E501


        :return: The subnet_ids of this ModifyScalingGroupRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._subnet_ids

    @subnet_ids.setter
    def subnet_ids(self, subnet_ids):
        """Sets the subnet_ids of this ModifyScalingGroupRequest.


        :param subnet_ids: The subnet_ids of this ModifyScalingGroupRequest.  # noqa: E501
        :type: list[str]
        """

        self._subnet_ids = subnet_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModifyScalingGroupRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModifyScalingGroupRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModifyScalingGroupRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    vpc

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from volcenginesdkcore.configuration import Configuration


class HaVipForDescribeHaVipsOutput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'associated_eip_address': 'str',
        'associated_eip_id': 'str',
        'associated_instance_ids': 'list[str]',
        'associated_instance_type': 'str',
        'created_at': 'str',
        'description': 'str',
        'ha_vip_id': 'str',
        'ha_vip_name': 'str',
        'ip_address': 'str',
        'master_instance_id': 'str',
        'status': 'str',
        'subnet_id': 'str',
        'updated_at': 'str',
        'vpc_id': 'str'
    }

    attribute_map = {
        'account_id': 'AccountId',
        'associated_eip_address': 'AssociatedEipAddress',
        'associated_eip_id': 'AssociatedEipId',
        'associated_instance_ids': 'AssociatedInstanceIds',
        'associated_instance_type': 'AssociatedInstanceType',
        'created_at': 'CreatedAt',
        'description': 'Description',
        'ha_vip_id': 'HaVipId',
        'ha_vip_name': 'HaVipName',
        'ip_address': 'IpAddress',
        'master_instance_id': 'MasterInstanceId',
        'status': 'Status',
        'subnet_id': 'SubnetId',
        'updated_at': 'UpdatedAt',
        'vpc_id': 'VpcId'
    }

    def __init__(self, account_id=None, associated_eip_address=None, associated_eip_id=None, associated_instance_ids=None, associated_instance_type=None, created_at=None, description=None, ha_vip_id=None, ha_vip_name=None, ip_address=None, master_instance_id=None, status=None, subnet_id=None, updated_at=None, vpc_id=None, _configuration=None):  # noqa: E501
        """HaVipForDescribeHaVipsOutput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._associated_eip_address = None
        self._associated_eip_id = None
        self._associated_instance_ids = None
        self._associated_instance_type = None
        self._created_at = None
        self._description = None
        self._ha_vip_id = None
        self._ha_vip_name = None
        self._ip_address = None
        self._master_instance_id = None
        self._status = None
        self._subnet_id = None
        self._updated_at = None
        self._vpc_id = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if associated_eip_address is not None:
            self.associated_eip_address = associated_eip_address
        if associated_eip_id is not None:
            self.associated_eip_id = associated_eip_id
        if associated_instance_ids is not None:
            self.associated_instance_ids = associated_instance_ids
        if associated_instance_type is not None:
            self.associated_instance_type = associated_instance_type
        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if ha_vip_id is not None:
            self.ha_vip_id = ha_vip_id
        if ha_vip_name is not None:
            self.ha_vip_name = ha_vip_name
        if ip_address is not None:
            self.ip_address = ip_address
        if master_instance_id is not None:
            self.master_instance_id = master_instance_id
        if status is not None:
            self.status = status
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if updated_at is not None:
            self.updated_at = updated_at
        if vpc_id is not None:
            self.vpc_id = vpc_id

    @property
    def account_id(self):
        """Gets the account_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The account_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this HaVipForDescribeHaVipsOutput.


        :param account_id: The account_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def associated_eip_address(self):
        """Gets the associated_eip_address of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The associated_eip_address of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._associated_eip_address

    @associated_eip_address.setter
    def associated_eip_address(self, associated_eip_address):
        """Sets the associated_eip_address of this HaVipForDescribeHaVipsOutput.


        :param associated_eip_address: The associated_eip_address of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._associated_eip_address = associated_eip_address

    @property
    def associated_eip_id(self):
        """Gets the associated_eip_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The associated_eip_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._associated_eip_id

    @associated_eip_id.setter
    def associated_eip_id(self, associated_eip_id):
        """Sets the associated_eip_id of this HaVipForDescribeHaVipsOutput.


        :param associated_eip_id: The associated_eip_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._associated_eip_id = associated_eip_id

    @property
    def associated_instance_ids(self):
        """Gets the associated_instance_ids of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The associated_instance_ids of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._associated_instance_ids

    @associated_instance_ids.setter
    def associated_instance_ids(self, associated_instance_ids):
        """Sets the associated_instance_ids of this HaVipForDescribeHaVipsOutput.


        :param associated_instance_ids: The associated_instance_ids of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: list[str]
        """

        self._associated_instance_ids = associated_instance_ids

    @property
    def associated_instance_type(self):
        """Gets the associated_instance_type of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The associated_instance_type of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._associated_instance_type

    @associated_instance_type.setter
    def associated_instance_type(self, associated_instance_type):
        """Sets the associated_instance_type of this HaVipForDescribeHaVipsOutput.


        :param associated_instance_type: The associated_instance_type of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._associated_instance_type = associated_instance_type

    @property
    def created_at(self):
        """Gets the created_at of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The created_at of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this HaVipForDescribeHaVipsOutput.


        :param created_at: The created_at of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def description(self):
        """Gets the description of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The description of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this HaVipForDescribeHaVipsOutput.


        :param description: The description of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def ha_vip_id(self):
        """Gets the ha_vip_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The ha_vip_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._ha_vip_id

    @ha_vip_id.setter
    def ha_vip_id(self, ha_vip_id):
        """Sets the ha_vip_id of this HaVipForDescribeHaVipsOutput.


        :param ha_vip_id: The ha_vip_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._ha_vip_id = ha_vip_id

    @property
    def ha_vip_name(self):
        """Gets the ha_vip_name of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The ha_vip_name of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._ha_vip_name

    @ha_vip_name.setter
    def ha_vip_name(self, ha_vip_name):
        """Sets the ha_vip_name of this HaVipForDescribeHaVipsOutput.


        :param ha_vip_name: The ha_vip_name of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._ha_vip_name = ha_vip_name

    @property
    def ip_address(self):
        """Gets the ip_address of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The ip_address of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this HaVipForDescribeHaVipsOutput.


        :param ip_address: The ip_address of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def master_instance_id(self):
        """Gets the master_instance_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The master_instance_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._master_instance_id

    @master_instance_id.setter
    def master_instance_id(self, master_instance_id):
        """Sets the master_instance_id of this HaVipForDescribeHaVipsOutput.


        :param master_instance_id: The master_instance_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._master_instance_id = master_instance_id

    @property
    def status(self):
        """Gets the status of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The status of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this HaVipForDescribeHaVipsOutput.


        :param status: The status of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def subnet_id(self):
        """Gets the subnet_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The subnet_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this HaVipForDescribeHaVipsOutput.


        :param subnet_id: The subnet_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def updated_at(self):
        """Gets the updated_at of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The updated_at of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this HaVipForDescribeHaVipsOutput.


        :param updated_at: The updated_at of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def vpc_id(self):
        """Gets the vpc_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501


        :return: The vpc_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :rtype: str
        """
        return self._vpc_id

    @vpc_id.setter
    def vpc_id(self, vpc_id):
        """Sets the vpc_id of this HaVipForDescribeHaVipsOutput.


        :param vpc_id: The vpc_id of this HaVipForDescribeHaVipsOutput.  # noqa: E501
        :type: str
        """

        self._vpc_id = vpc_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HaVipForDescribeHaVipsOutput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HaVipForDescribeHaVipsOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HaVipForDescribeHaVipsOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    redis

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: common-version
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from volcenginesdkredis.models.account_for_list_db_account_output import AccountForListDBAccountOutput
from volcenginesdkredis.models.allow_list_for_describe_allow_lists_output import AllowListForDescribeAllowListsOutput
from volcenginesdkredis.models.associate_allow_list_request import AssociateAllowListRequest
from volcenginesdkredis.models.associate_allow_list_response import AssociateAllowListResponse
from volcenginesdkredis.models.associated_instance_for_describe_allow_list_detail_output import AssociatedInstanceForDescribeAllowListDetailOutput
from volcenginesdkredis.models.backup_for_describe_backups_output import BackupForDescribeBackupsOutput
from volcenginesdkredis.models.backup_point_download_url_for_describe_backup_point_download_urls_output import BackupPointDownloadUrlForDescribeBackupPointDownloadUrlsOutput
from volcenginesdkredis.models.capacity_for_describe_db_instance_detail_output import CapacityForDescribeDBInstanceDetailOutput
from volcenginesdkredis.models.capacity_for_describe_db_instances_output import CapacityForDescribeDBInstancesOutput
from volcenginesdkredis.models.create_allow_list_request import CreateAllowListRequest
from volcenginesdkredis.models.create_allow_list_response import CreateAllowListResponse
from volcenginesdkredis.models.create_backup_request import CreateBackupRequest
from volcenginesdkredis.models.create_backup_response import CreateBackupResponse
from volcenginesdkredis.models.create_db_account_request import CreateDBAccountRequest
from volcenginesdkredis.models.create_db_account_response import CreateDBAccountResponse
from volcenginesdkredis.models.create_db_endpoint_public_address_request import CreateDBEndpointPublicAddressRequest
from volcenginesdkredis.models.create_db_endpoint_public_address_response import CreateDBEndpointPublicAddressResponse
from volcenginesdkredis.models.create_db_instance_request import CreateDBInstanceRequest
from volcenginesdkredis.models.create_db_instance_response import CreateDBInstanceResponse
from volcenginesdkredis.models.delete_allow_list_request import DeleteAllowListRequest
from volcenginesdkredis.models.delete_allow_list_response import DeleteAllowListResponse
from volcenginesdkredis.models.delete_db_account_request import DeleteDBAccountRequest
from volcenginesdkredis.models.delete_db_account_response import DeleteDBAccountResponse
from volcenginesdkredis.models.delete_db_endpoint_public_address_request import DeleteDBEndpointPublicAddressRequest
from volcenginesdkredis.models.delete_db_endpoint_public_address_response import DeleteDBEndpointPublicAddressResponse
from volcenginesdkredis.models.delete_db_instance_request import DeleteDBInstanceRequest
from volcenginesdkredis.models.delete_db_instance_response import DeleteDBInstanceResponse
from volcenginesdkredis.models.describe_allow_list_detail_request import DescribeAllowListDetailRequest
from volcenginesdkredis.models.describe_allow_list_detail_response import DescribeAllowListDetailResponse
from volcenginesdkredis.models.describe_allow_lists_request import DescribeAllowListsRequest
from volcenginesdkredis.models.describe_allow_lists_response import DescribeAllowListsResponse
from volcenginesdkredis.models.describe_backup_plan_request import DescribeBackupPlanRequest
from volcenginesdkredis.models.describe_backup_plan_response import DescribeBackupPlanResponse
from volcenginesdkredis.models.describe_backup_point_download_urls_request import DescribeBackupPointDownloadUrlsRequest
from volcenginesdkredis.models.describe_backup_point_download_urls_response import DescribeBackupPointDownloadUrlsResponse
from volcenginesdkredis.models.describe_backups_request import DescribeBackupsRequest
from volcenginesdkredis.models.describe_backups_response import DescribeBackupsResponse
from volcenginesdkredis.models.describe_db_instance_detail_request import DescribeDBInstanceDetailRequest
from volcenginesdkredis.models.describe_db_instance_detail_response import DescribeDBInstanceDetailResponse
from volcenginesdkredis.models.describe_db_instance_params_request import DescribeDBInstanceParamsRequest
from volcenginesdkredis.models.describe_db_instance_params_response import DescribeDBInstanceParamsResponse
from volcenginesdkredis.models.describe_db_instances_request import DescribeDBInstancesRequest
from volcenginesdkredis.models.describe_db_instances_response import DescribeDBInstancesResponse
from volcenginesdkredis.models.describe_node_ids_request import DescribeNodeIdsRequest
from volcenginesdkredis.models.describe_node_ids_response import DescribeNodeIdsResponse
from volcenginesdkredis.models.describe_pitr_time_window_request import DescribePitrTimeWindowRequest
from volcenginesdkredis.models.describe_pitr_time_window_response import DescribePitrTimeWindowResponse
from volcenginesdkredis.models.describe_regions_request import DescribeRegionsRequest
from volcenginesdkredis.models.describe_regions_response import DescribeRegionsResponse
from volcenginesdkredis.models.describe_slow_logs_request import DescribeSlowLogsRequest
from volcenginesdkredis.models.describe_slow_logs_response import DescribeSlowLogsResponse
from volcenginesdkredis.models.describe_zones_request import DescribeZonesRequest
from volcenginesdkredis.models.describe_zones_response import DescribeZonesResponse
from volcenginesdkredis.models.disassociate_allow_list_request import DisassociateAllowListRequest
from volcenginesdkredis.models.disassociate_allow_list_response import DisassociateAllowListResponse
from volcenginesdkredis.models.instance_detail_for_describe_backups_output import InstanceDetailForDescribeBackupsOutput
from volcenginesdkredis.models.instance_for_describe_db_instances_output import InstanceForDescribeDBInstancesOutput
from volcenginesdkredis.models.list_db_account_request import ListDBAccountRequest
from volcenginesdkredis.models.list_db_account_response import ListDBAccountResponse
from volcenginesdkredis.models.modify_allow_list_request import ModifyAllowListRequest
from volcenginesdkredis.models.modify_allow_list_response import ModifyAllowListResponse
from volcenginesdkredis.models.modify_backup_plan_request import ModifyBackupPlanRequest
from volcenginesdkredis.models.modify_backup_plan_response import ModifyBackupPlanResponse
from volcenginesdkredis.models.modify_db_account_request import ModifyDBAccountRequest
from volcenginesdkredis.models.modify_db_account_response import ModifyDBAccountResponse
from volcenginesdkredis.models.modify_db_instance_charge_type_request import ModifyDBInstanceChargeTypeRequest
from volcenginesdkredis.models.modify_db_instance_charge_type_response import ModifyDBInstanceChargeTypeResponse
from volcenginesdkredis.models.modify_db_instance_deletion_protection_policy_request import ModifyDBInstanceDeletionProtectionPolicyRequest
from volcenginesdkredis.models.modify_db_instance_deletion_protection_policy_response import ModifyDBInstanceDeletionProtectionPolicyResponse
from volcenginesdkredis.models.modify_db_instance_name_request import ModifyDBInstanceNameRequest
from volcenginesdkredis.models.modify_db_instance_name_response import ModifyDBInstanceNameResponse
from volcenginesdkredis.models.modify_db_instance_node_number_request import ModifyDBInstanceNodeNumberRequest
from volcenginesdkredis.models.modify_db_instance_node_number_response import ModifyDBInstanceNodeNumberResponse
from volcenginesdkredis.models.modify_db_instance_params_request import ModifyDBInstanceParamsRequest
from volcenginesdkredis.models.modify_db_instance_params_response import ModifyDBInstanceParamsResponse
from volcenginesdkredis.models.modify_db_instance_shard_capacity_request import ModifyDBInstanceShardCapacityRequest
from volcenginesdkredis.models.modify_db_instance_shard_capacity_response import ModifyDBInstanceShardCapacityResponse
from volcenginesdkredis.models.modify_db_instance_shard_number_request import ModifyDBInstanceShardNumberRequest
from volcenginesdkredis.models.modify_db_instance_shard_number_response import ModifyDBInstanceShardNumberResponse
from volcenginesdkredis.models.modify_db_instance_subnet_request import ModifyDBInstanceSubnetRequest
from volcenginesdkredis.models.modify_db_instance_subnet_response import ModifyDBInstanceSubnetResponse
from volcenginesdkredis.models.modify_db_instance_vpc_auth_mode_request import ModifyDBInstanceVpcAuthModeRequest
from volcenginesdkredis.models.modify_db_instance_vpc_auth_mode_response import ModifyDBInstanceVpcAuthModeResponse
from volcenginesdkredis.models.option_for_describe_db_instance_params_output import OptionForDescribeDBInstanceParamsOutput
from volcenginesdkredis.models.param_for_describe_db_instance_params_output import ParamForDescribeDBInstanceParamsOutput
from volcenginesdkredis.models.param_value_for_modify_db_instance_params_input import ParamValueForModifyDBInstanceParamsInput
from volcenginesdkredis.models.region_for_describe_regions_output import RegionForDescribeRegionsOutput
from volcenginesdkredis.models.restart_db_instance_request import RestartDBInstanceRequest
from volcenginesdkredis.models.restart_db_instance_response import RestartDBInstanceResponse
from volcenginesdkredis.models.restore_db_instance_request import RestoreDBInstanceRequest
from volcenginesdkredis.models.restore_db_instance_response import RestoreDBInstanceResponse
from volcenginesdkredis.models.slow_query_for_describe_slow_logs_output import SlowQueryForDescribeSlowLogsOutput
from volcenginesdkredis.models.start_continuous_backup_request import StartContinuousBackupRequest
from volcenginesdkredis.models.start_continuous_backup_response import StartContinuousBackupResponse
from volcenginesdkredis.models.stop_continuous_backup_request import StopContinuousBackupRequest
from volcenginesdkredis.models.stop_continuous_backup_response import StopContinuousBackupResponse
from volcenginesdkredis.models.upgrade_allow_list_version_request import UpgradeAllowListVersionRequest
from volcenginesdkredis.models.upgrade_allow_list_version_response import UpgradeAllowListVersionResponse
from volcenginesdkredis.models.visit_addr_for_describe_db_instance_detail_output import VisitAddrForDescribeDBInstanceDetailOutput
from volcenginesdkredis.models.vpc_info_for_describe_backups_output import VpcInfoForDescribeBackupsOutput
from volcenginesdkredis.models.zone_for_describe_zones_output import ZoneForDescribeZonesOutput
